set IMAGE_ 257
set PHYSICAL_ 258
set AMPLIFIER_ 259
set DETECTOR_ 260
set WCS_ 261
set WCSA_ 262
set WCSB_ 263
set WCSC_ 264
set WCSD_ 265
set WCSE_ 266
set WCSF_ 267
set WCSG_ 268
set WCSH_ 269
set WCSI_ 270
set WCSJ_ 271
set WCSK_ 272
set WCSL_ 273
set WCSM_ 274
set WCSN_ 275
set WCSO_ 276
set WCSP_ 277
set WCSQ_ 278
set WCSR_ 279
set WCSS_ 280
set WCST_ 281
set WCSU_ 282
set WCSV_ 283
set WCSW_ 284
set WCSX_ 285
set WCSY_ 286
set WCSZ_ 287
set BUTTONS_ 288
set COLORBAR_ 289
set COLORBARNUMERICS_ 290
set FILENAME_ 291
set FRAME_ 292
set GRAPH_ 293
set HORIZONTAL_ 294
set HORZGRAPH_ 295
set ICONS_ 296
set INFO_ 297
set KEYWORD_ 298
set KEYVALUE_ 299
set LAYOUT_ 300
set LOWHIGH_ 301
set MAGNIFIER_ 302
set MINMAX_ 303
set MULTI_ 304
set OBJECT_ 305
set PANNER_ 306
set UNITS_ 307
set VERTGRAPH_ 308
set VERTICAL_ 309
set RED_ 310
set GREEN_ 311
set BLUE_ 312
